#undef HAVE_LC_MESSAGES
#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_STPCPY
#undef HAVE_NCURSES
#undef HAVE_DIRENT_H
#undef HAVE_SYS_NDIR_H
#undef HAVE_SYS_DIR_H
#undef HAVE_NDIR_H

#undef SO_EXTENSION
#undef SYSCONF_DIR
#undef LOCALEDIR
#undef DOCDIR
#undef PLUGINS_DIR
#undef SCRIPTS_DIR
#undef GLADE_DIR
#undef TIPS_FILE
#undef SUPERFLUOUS
#undef COMPATIBILITY
#undef DEBUG_GABY
#undef USE_GNOME
#undef USE_PYTHON
#undef NO_GUI
#undef FOLLOW_MIGUEL
#undef USE_DEBIAN
#undef HAVE_PYGTK
#undef HAVE_LIBGLADE

#undef HAVE_IMLIB
#undef HAVE_GDKPIXBUF
#undef HAVE_ESD
#undef HAVE_LIBXML

#undef PACKAGE
#undef VERSION

#undef GETOPT_AVAILABLE
#undef GETOPTLONG_AVAILABLE

#undef HAVE_TMPNAM

#undef USE_POSTGRESQL

